@@ -13,10 +13,12 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+from quocslib.stoppingcriteria.StoppingCriteria import StoppingCriteria
+
+import numpy as np
 
 
 class Wrap:
-
     def __init__(self, args):
         self.args = args
         self.calls_number = [0]
@@ -38,12 +40,16 @@ class Wrap:
 
 
 class DirectSearchMethod:
+    sc_obj: StoppingCriteria
 
     def __init__(self):
         # TODO Set the initial wrapper function with the target function and the optional arguments
         # TODO Integrate here the callback function for user interruption
         pass
 
+    def run_dsm(self, routine_call: callable, x0: np.array, **kwargs):
+        raise NotImplementedError("The direct search method must implement the run_dsm function")
+
     @staticmethod
     def _get_wrapper(args, func):
         wrap = Wrap(args)
