@@ -40,23 +40,20 @@ class GradientFreeTemplate(DirectSearchMethod):
         # Stopping criteria object
         self.sc_obj = NelderMeadStoppingCriteria(stopping_criteria)
 
-    def run_dsm(self, func, x0, args=(), initial_simplex=None, max_eval_total=None) -> dict:
+    def run_dsm(self, func, x0, args=(), initial_simplex=None, drift_comp_minutes=0.0) -> dict:
         """
 
         :param callable func: Function tbe called at every function evaluation
         :param np.array x0: initial point
         :param tuple args: Further arguments
         :param np.array initial_simplex: Starting simplex for the Nelder Mead evaluation
-        :param int max_eval_total: Maximum iteration number of function evaluations in total
+        :param float drift_comp_minutes: Compensate for drift after this number of minutes
         :return:
         """
         # Creation of the communication function for the OptimizationAlgorithm object
         calls_number, func = self._get_wrapper(args, func)
         # Set to false is_converged
         self.sc_obj.is_converged = False
-        # Update function evaluations number
-        if max_eval_total is not None:
-            self.sc_obj.max_eval_total = max_eval_total
         # Initialize the iteration number
         iterations = 0
         # Initialize hyper-parameters if any
@@ -161,7 +158,8 @@ class GradientFreeTemplate(DirectSearchMethod):
             if self.callback is not None:
                 if not self.callback():
                     self.sc_obj.is_converged = True
-                    self.sc_obj.terminate_reason = "User stopped the optimization"
+                    self.sc_obj.terminate_reason = "User stopped the optimization or higher order " \
+                                                   "stopping criterion has been reached"
             # Check stopping criteria
             self.sc_obj.check_stopping_criteria(sim, fsim, calls_number[0])
         # END of while loop
